"""
TOF related entities which did not fit anywhere else 
"""

from .. import _gondola_core  as _gc 

from . import analysis

RBPaddleID          = _gc.tof.RBPaddleID
TofDetectorStatus   = _gc.tof.TofDetectorStatus
TofCommandCode      = _gc.tof.TofCommandCode
TofCommand          = _gc.tof.TofCommand
TofOperationMode    = _gc.tof.TofOperationMode
BuildStrategy       = _gc.tof.BuildStrategy
PreampBiasConfig    = _gc.tof.PreampBiasConfig
RBChannelMaskConfig = _gc.tof.RBChannelMaskConfig
TriggerConfig       = _gc.tof.TriggerConfig
TofRunConfig        = _gc.tof.TofRunConfig
TofCuts             = _gc.tof.TofCuts
to_board_id_string  = _gc.tof.to_board_id_string
TofAnalysis         = analysis.TofAnalysis

